==> modx-2.1.5-pl-ja.zip: modx-2.1.5-pl-ja/core/lexicon/ja/package_builder.inc.php <==
<?php
/**
 * Package Builder Japanese lexicon topic
 *
 * @language ja
 * @package modx
 * @subpackage lexicon
 * @author shimojo http://www.priqia.com/
 */
$_lang['as_system_settings'] = 'システム設定';
$_lang['as_context_settings'] = 'コンテキストの設定';
$_lang['as_lexicon_entries'] = 'レキシコン登録';
$_lang['as_lexicon_topics'] = 'レキシコン';
$_lang['build'] = 'ビルド';
$_lang['class_key'] = 'クラスキー';
$_lang['class_key_desc'] = 'The type of object you would like to map to the vehicle.';
$_lang['class_key_custom'] = 'Or Custom Class';
$_lang['class_key_custom_desc'] = 'ここでは、上記のリストにないカスタムxPDOオブジェクトのクラス名を指定することができます。';
$_lang['file'] = 'ファイル';
$_lang['index'] = 'インデックス';
$_lang['object'] = 'オブジェクト';
$_lang['object_id'] = 'オブジェクトID';
$_lang['object_id_desc'] = 'マップしたい正確なオブジェクトです(必須項目)';
$_lang['package_autoselects'] = 'Package Auto-Includes';
$_lang['package_autoselects_desc'] = 'パッケージのビルドで自動的に取り込みたいリソースを選択して下さい。付記 : コアからビルドする場合は、全てチェックしないことをお勧めします。';
$_lang['package_build'] = 'パッケージをビルド';
$_lang['package_build_desc'] = 'パッケージをビルドすることができます。一度ビルドすると、core/packages ディレクトリに保存されます。';
$_lang['package_build_err'] = 'パッケージのビルド中にエラーが発生しました。';
$_lang['package_build_xml'] = 'XMLからパッケージをビルド';
$_lang['package_build_xml_desc'] = 'コンポーネントから有効なビルドXMLファイルを選択して下さい。';
$_lang['package_builder'] = 'パッケージビルダー';
$_lang['package_built'] = 'パッケージはビルドされました。';
$_lang['package_info'] = 'パッケージ情報';
$_lang['package_info_desc'] = '最初に、名前やバージョンやリリース情報等のパッケージ情報を指定してください。';
$_lang['package_method'] = 'パッケージング方法選択';
$_lang['package_method_desc'] = '使用したいパッケージのビルド方法を選択して下さい。';
$_lang['php_script'] = 'PHPスクリプト';
$_lang['preserve_keys'] = 'プライマリキー';
$_lang['preserve_keys_desc'] = '現在のDBにある値にプライマリキーを保存します。';
$_lang['release'] = 'リリース';
$_lang['resolve_files'] = 'Resolve Files';
$_lang['resolve_files_desc'] = 'When checked, this will resolve the files specified in the resolvers.';
$_lang['resolve_php'] = 'Resolve PHP Scripts';
$_lang['resolve_php_desc'] = 'When checked, this will resolve the PHP scripts specified in the resolvers.';
$_lang['resolver_add'] = 'Add Resolver';
$_lang['resolver_create'] = 'Create Resolver';
$_lang['resolver_name_desc'] = 'The name of the resolver. Used for organizational purposes.';
$_lang['resolver_remove'] = 'Remove Resolver';
$_lang['resolver_remove_confirm'] = 'Are you sure you want to delete this resolver?';
$_lang['resolver_source_desc'] = 'The absolute path of the source of the resolver. If it is a file resolver, select the directory of the files you\'d like to copy. If a PHP Script, specify the script. Example: <br /><br />/public_html/modx/_build/components/demo/';
$_lang['resolver_target_desc'] = 'The absolute path target for where the resolver should put files or actions. Usually you won\'t have to change this. Example: <br /><br />return MODX_ASSETS_PATH . "snippets/";';
$_lang['resolver_type_desc'] = 'File resolvers make sure to copy all the files in the source directory to the target. PHP Script resolvers execute the source file as PHP.';
$_lang['resolvers'] = 'Resolvers';
$_lang['source'] = 'ソース';
$_lang['target'] = 'ターゲット';
$_lang['type'] = 'タイプ';
$_lang['unique_key'] = 'ユニークキー';
$_lang['unique_key_desc'] = 'A unique key identifying how to search for the object. Can be a string or comma-delimited list. Examples: <br />"name" for modPlugin<br />"templatename" for modTemplate<br />Or more complex, "pluginid,evtid" for modPluginEvent';
$_lang['update_object'] = 'オブジェクトをアップデート';
$_lang['update_object_desc'] = 'If checked, this will update the object if it is found. If not checked, it will not save the object if it is already found.';
$_lang['use_wizard'] = 'ウィザードを使用';
$_lang['use_xml'] = 'XMLファイルからビルド';
$_lang['vehicle'] = 'ビークル';
$_lang['vehicle_add'] = 'ビークルを追加';
$_lang['vehicle_create'] = 'ビークルを作成';
$_lang['vehicle_remove'] = 'ビークルを削除';
$_lang['vehicle_remove_confirm'] = 'Are you sure you want to delete this vehicle?';
$_lang['vehicles'] = 'ビークル';
$_lang['vehicles_add'] = 'Add Vehicles';
$_lang['vehicles_desc'] = 'Vehicles are the objects that are contained in the package. You may add them in here.';
$_lang['version'] = 'バージョン';
$_lang['xml_file_err_upload'] = 'XMLファイルのアップロード中にエラーが発生しました。';

==> modx-2.3.3-pl-ja.zip: modx-2.3.3-pl-ja/core/lexicon/ja/package_builder.inc.php <==
<?php
/**
 * Package Builder English lexicon topic
 *
 * @language en
 * @package modx
 * @subpackage lexicon
 */
$_lang['as_system_settings'] = 'システム設定';
$_lang['as_context_settings'] = 'コンテキストの設定';
$_lang['as_lexicon_entries'] = 'レキシコン登録';
$_lang['as_lexicon_topics'] = 'レキシコン';
$_lang['build'] = 'ビルド';
$_lang['class_key'] = 'クラスキー';
$_lang['class_key_desc'] = 'ビークルにマップしたいオブジェクトタイプを指定します。';
$_lang['class_key_custom'] = 'カスタムクラス';
$_lang['class_key_custom_desc'] = 'ここでは、上記のリストにないカスタムxPDOオブジェクトのクラス名を指定することができます。';
$_lang['file'] = 'ファイル';
$_lang['index'] = 'インデックス';
$_lang['object'] = 'オブジェクト';
$_lang['object_id'] = 'オブジェクトID';
$_lang['object_id_desc'] = 'マップしたい正確なオブジェクトです（必須項目）';
$_lang['package_autoselects'] = 'パッケージのオートインクルード';
$_lang['package_autoselects_desc'] = 'パッケージのビルドで自動的に取り込みたいリソースを選択してください。付記 : コアからビルドする場合は、全てチェックしないことをお勧めします。';
$_lang['package_build'] = 'パッケージをビルド';
$_lang['package_build_desc'] = 'パッケージをビルドすることができます。一度ビルドすると、core/packages ディレクトリに保存されます。';
$_lang['package_build_err'] = 'パッケージのビルド中にエラーが発生しました。';
$_lang['package_build_xml'] = 'XMLからパッケージをビルド';
$_lang['package_build_xml_desc'] = 'コンポーネントから有効なビルドXMLファイルを選択してください。';
$_lang['package_builder'] = 'パッケージビルダー';
$_lang['package_built'] = 'パッケージはビルドされました。';
$_lang['package_info'] = 'パッケージ情報';
$_lang['package_info_desc'] = '最初に、名前やバージョンやリリース情報等のパッケージ情報を指定してください。';
$_lang['package_method'] = 'パッケージング方法選択';
$_lang['package_method_desc'] = '使用したいパッケージのビルド方法を選択してください。';
$_lang['php_script'] = 'PHPスクリプト';
$_lang['preserve_keys'] = 'プライマリキー';
$_lang['preserve_keys_desc'] = '現在のDBにある値にプライマリキーを保存します。';
$_lang['release'] = 'リリース';
$_lang['resolve_files'] = 'Resolve Files';
$_lang['resolve_files_desc'] = 'When checked, this will resolve the files specified in the resolvers.';
$_lang['resolve_php'] = 'Resolve PHP Scripts';
$_lang['resolve_php_desc'] = 'When checked, this will resolve the PHP scripts specified in the resolvers.';
$_lang['resolver_add'] = 'リゾルバを追加';
$_lang['resolver_create'] = 'リゾルバを作成';
$_lang['resolver_name_desc'] = 'リゾルバの名前（管理目的で使用します）。';
$_lang['resolver_remove'] = 'リゾルバを削除';
$_lang['resolver_remove_confirm'] = 'このリゾルバを削除してもよろしいですか？';
$_lang['resolver_source_desc'] = 'リゾルバのソースを絶対パスで指定します。ファイルリゾルバの場合、コピーしたいファイルのディレクトリを指定します。PHPスクリプトの場合、スクリプトを指定します。例: <br /><br />/public_html/modx/_build/components/demo/';
$_lang['resolver_target_desc'] = 'The absolute path target for where the resolver should put files or actions. Usually you won\'t have to change this. Example: <br /><br />return MODX_ASSETS_PATH . "snippets/";';
$_lang['resolver_type_desc'] = 'File resolvers make sure to copy all the files in the source directory to the target. PHP Script resolvers execute the source file as PHP.';
$_lang['resolvers'] = 'リゾルバ';
$_lang['source'] = 'ソース';
$_lang['target'] = 'ターゲット';
$_lang['type'] = 'タイプ';
$_lang['unique_key'] = 'ユニークキー';
$_lang['unique_key_desc'] = 'A unique key identifying how to search for the object. Can be a string or comma-delimited list. Examples: <br />"name" for modPlugin<br />"templatename" for modTemplate<br />Or more complex, "pluginid,evtid" for modPluginEvent';
$_lang['update_object'] = 'オブジェクトをアップデート';
$_lang['update_object_desc'] = 'チェックした場合、発見したオブジェクトをアップデートします。チェックしない場合は、発見済みのオブジェクトを保存しません。';
$_lang['use_wizard'] = 'ウィザードを使用';
$_lang['use_xml'] = 'XMLファイルからビルド';
$_lang['vehicle'] = 'ビークル';
$_lang['vehicle_add'] = 'ビークルを追加';
$_lang['vehicle_create'] = 'ビークルを作成';
$_lang['vehicle_remove'] = 'ビークルを削除';
$_lang['vehicle_remove_confirm'] = 'このビークルを本当に削除してもよろしいですか？';
$_lang['vehicles'] = 'ビークル';
$_lang['vehicles_add'] = 'ビークルを追加';
$_lang['vehicles_desc'] = 'ビークルは、パッケージに含まれるオブジェクトです。ここではビークルを追加できます。';
$_lang['version'] = 'バージョン';
$_lang['xml_file_err_upload'] = 'XMLファイルのアップロード中にエラーが発生しました。';
